/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged from '../config/logged';
import { Player } from '../classes/Player';
import { errorRequestTreatment } from '../global/errors';

const getPlayersRequest = ({ departmentId, teamId, name, pageSize, page, email, functionId }) => {

    let url = '';
    let passed = false;

    if (departmentId) {
        if (passed) url = url + '&departmentId=' + departmentId;
        else {
            url = '?departmentId=' + departmentId;
            passed = true;
        }
    }
    else if (teamId) {
        if (passed) url = url + '&teamId=' + teamId;
        else {
            url = '?teamId=' + teamId;
            passed = true;
        }
    }
    else if (name) {
        if (passed) url = url + '&name=' + name;
        else {
            url = '?name=' + name;
            passed = true;
        }
    }
    else if (pageSize) {
        if (passed) url = url + '&pageSize=' + pageSize;
        else {
            url = '?pageSize=' + pageSize;
            passed = true;
        }
    }
    else if (page) {
        if (passed) url = url + '&page=' + page;
        else {
            url = '?page=' + page;
            passed = true;
        }
    }
    else if (email) {
        if (passed) url = url + '&email=' + email;
        else {
            url = '?email=' + email;
            passed = true;
        }
    }
    else if (functionId) {
        if (passed) url = url + '&functionId=' + functionId;
        else {
            url = '?functionId=' + functionId;
            passed = true;
        }
    }

    console.log(url);

    return logged.get('/user' + url)
        .then(res => {
            let data    = res.data;
            let message = data.message;
            let object  = data.object;

            if (object.totalFound > 0) {
                let listOfPlayers = object.list;
                let players = [];

                listOfPlayers.map(player => players.push(new Player(player)));

                return {
                    result  : 'GET_ALL_PLAYERS_SUCCESS',
                    message : message,
                    players : players
                }
            }

            return {
                result : 'GET_ALL_PLAYERS_FAIL',
                data   : message
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_ALL_PLAYERS') });
};

export function getAllPlayers() {
    return getPlayersRequest({teamId: 42, pageSize: 2})
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_ALL_PLAYERS_SUCCESS') {
                result = {
                    message : res.message,
                    players : res.players,
                }
            }
            else if (res.result === 'GET_ALL_PLAYERS_FAIL') {
                result = {
                    message : res.message,
                    players : null,
                }
            }

            return result
        });
}

module.exports = {
    getAllPlayers
};
